DataV2 class

Data V2

Constructors

DataV2({required String name, required String symbol, required String uri, required int sellerFeeBasisPoints, List<MetadataCreator>? creators, MetadataCollection? collection, MetadataUses? uses})
const

Properties

collection → MetadataCollection?
This field optionally links to the Mint address of another NFT that acts as a Collection NFT.
final
creators → List<MetadataCreator>?
An array of creators and their share of the royalties. This array is limited to 5 creators. Note that, because the Creators field is an array of variable length, we cannot guarantee the byte position of any field that follows.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The on-chain name of the token, limited to 32 bytes. For instance "Degen Ape #1 ".
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sellerFeeBasisPoints → int
The royalties shared by the creators in basis points — i.e. 550 means 5.5%. Whilst this field is used by virtually all NFT marketplaces, it is not enforced by the Token Metadata program itself.
final
symbol → String
The on-chain symbol of the token, limited to 10 bytes. For instance "DAPE".
final
uri → String
The URI of the token, limited to 200 bytes. This URI points to an off-chain JSON file that contains additional data following a certain standard. You can learn more about this JSON standard here. The JSON file can either be stored in a traditional server (e.g. using AWS) or using a permanent storage solution such as using Arweave.
final
uses → MetadataUses?
This field can make NFTs usable. Meaning you can load it with a certain amount of "uses" and use it until it has run out. You can learn more about using NFTs here.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited