ValidatorList class

Validator List

Inheritance

Constructors

ValidatorList({required ValidatorListHeader header, required List<ValidatorStakeInfo> validators})
Storage list for all validator stake accounts in the pool.
const
ValidatorList.fromAccountInfo(AccountInfo info)
factory
ValidatorList.fromJson(Map<String, dynamic> json)
factory

Properties

borshSchema → BorshSchema
Maps this class' properties to codecs.
no setteroverride
hashCode → u64
The hash code for this object.
no setterinherited
Data outside of the validator list, separated out for cheaper deserializations
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validators → List<ValidatorStakeInfo>
List of stake info for each validator in the pool
final

Methods

borshSize() → u64
Returns the serialized byte length of this instance.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBorsh() → Iterable<int>
Serializes this instance into a buffer.
inherited
toJson() → Map<String, dynamic>
Serialises this class into a JSON object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codec → BorshStructCodec
no setter