InflationGovernor class

Inflation Governor

Inheritance

Constructors

InflationGovernor({required f64 initial, required f64 terminal, required f64 taper, required f64 foundation, required f64? foundationTerm})
Inflation governor.
const
InflationGovernor.fromJson(Map<String, dynamic> json)
Creates an instance of this class from the constructor parameters defined in the json object.
factory

Properties

foundation f64
The percentage of total inflation allocated to the foundation.
final
foundationTerm f64?
The duration of foundation pool inflation in years.
final
hashCode int
The hash code for this object.
no setterinherited
initial f64
The initial inflation percentage from time 0.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taper f64
The rate per year at which inflation is lowered. Rate reduction is derived using the target slot time in the genesis config.
final
terminal f64
The terminal inflation percentage.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialises this class into a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

tryFromJson(Map<String, dynamic>? json) InflationGovernor?
Creates an instance of this class from the constructor parameters defined in the json object.
override