InflationGovernor class
Inflation Governor
Properties
-
foundation
→ f64
-
The percentage of total inflation allocated to the foundation.
final
-
foundationTerm
→ f64?
-
The duration of foundation pool inflation in years.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
initial
→ f64
-
The initial inflation percentage from time 0.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
taper
→ f64
-
The rate per year at which inflation is lowered. Rate reduction is derived using the target
slot time in the genesis config.
final
-
terminal
→ f64
-
The terminal inflation percentage.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Serialises
this class into a JSON object.
override
-
toString()
→ String
-
A string representation of this object.
inherited